@@ -24,7 +24,7 @@ class EnviarPedido(Enviar):
         self.exige_autenticacao = True
         self.processa_resposta = True
         self.url = "https://api-3t.{}paypal.com/nvp".format(self.sandbox)
-        self.grava_identificador = True
+        self.deve_gravar_dados_de_pagamento = True
         self.headers = {"Content-Type": "application/x-www-form-urlencoded; charset=utf-8"}
         self.formato_de_envio = FormatoDeEnvio.form_urlencode
 
