@@ -102,7 +102,7 @@ class Registro(RegistroBase):
         return self.chave_status in self.dados
 
     @property
-    def grava_identificador(self):
+    def deve_gravar_dados_de_pagamento(self):
         return "paymentinfo_0_transactionid" in self.dados
 
     @property
